@@ -1,7 +1,7 @@
 from __future__ import division
 from copy import copy
 import itertools
-import glob
+import kabuki
 import os
 
 import unittest
@@ -58,7 +58,14 @@ class TestSingleBreakdown(unittest.TestCase):
     def runTest(self):
         return
 
-    def test_HDDM(self, assert_=False):
+    def test_HLBA(self):
+        params = hddm.generate.gen_rand_params()
+        data, params_true = hddm.generate.gen_rand_data(params, size=10, subjs=10)
+        model = hddm.models.HLBA(data)
+        model.find_starting_values()
+        model.sample(self.iter, burn=self.burn)
+
+    def test_HDDM(self):
         for include, model_class in itertools.product(self.includes, self.model_classes):
             params = hddm.generate.gen_rand_params(include=include)
             data, params_true = hddm.generate.gen_rand_data(params, size=10, subjs=1)
@@ -68,7 +75,18 @@ class TestSingleBreakdown(unittest.TestCase):
 
         return model.mc
 
-    def test_HDDM_group(self, assert_=False):
+    def test_HDDM_split_std(self):
+        data, _ = hddm.generate.gen_rand_data({'cond1': {'v':0, 'a':2, 't':.3, 'z': .5, 'sv': .1, 'st': .1, 'sz': .1},
+                                               'cond2': {'v':0, 'a':2, 't':.3, 'z': .5, 'sv': .1, 'st': .1, 'sz': .1}})
+
+        for param in ['a', 'v', 'z', 't']:
+            model = hddm.HDDM(data, include='all', depends_on={param: 'condition'}, is_group_model=True, std_depends=True)
+            idx = model.nodes_db.knode_name == param + '_std'
+            self.assertEqual(len(model.nodes_db.node[idx]), 2)
+
+        return model.mc
+
+    def test_HDDM_group(self):
         for include, model_class in itertools.product(self.includes, self.model_classes):
             params = hddm.generate.gen_rand_params(include=include)
             data, params_true = hddm.generate.gen_rand_data(params, size=10, subjs=4)
@@ -78,7 +96,7 @@ class TestSingleBreakdown(unittest.TestCase):
 
         return model.mc
 
-    def test_HDDM_group_only_group_nodes(self, assert_=False):
+    def test_HDDM_group_only_group_nodes(self):
         group_only_nodes = ['v', 'a', 'z', 't']
         for nodes, model_class in itertools.product(group_only_nodes, self.model_classes):
             params = hddm.generate.gen_rand_params(include=nodes)
@@ -88,7 +106,7 @@ class TestSingleBreakdown(unittest.TestCase):
                 self.assertNotIn(node+'_subj', model.nodes_db.index)
                 self.assertIn(node, model.nodes_db.index)
 
-    def test_HDDM_load_save(self, assert_=False):
+    def test_HDDM_load_save(self):
         include = ['z', 'sz', 'st', 'sv']
         dbs = ['pickle', 'sqlite']
         params = hddm.generate.gen_rand_params(include=include)
@@ -101,7 +119,7 @@ class TestSingleBreakdown(unittest.TestCase):
                 model = model_class(data, 'v ~ cov', include=include, is_group_model=True)
             else:
                 model = model_class(data, include=include, is_group_model=True)
-            model.sample(50, dbname='test.db', db=db)
+            model.sample(100, dbname='test.db', db=db)
             model.save('test.model')
             m_load = hddm.load('test.model')
             os.remove('test.db')
@@ -112,37 +130,37 @@ class TestSingleBreakdown(unittest.TestCase):
         data, params_subj = hddm.generate.gen_rand_data(subjs=4, params=params, size=10)
         m = hddm.HDDMTruncated(data)
         m.sample(self.iter, burn=self.burn)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'], pm.Normal)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['mu'], pm.Normal)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['tau'], pm.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['tau'].parents['x'], pm.Uniform)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'], pm.TruncatedNormal)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['mu'], pm.Uniform)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['tau'], pm.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['tau'].parents['x'], pm.Uniform)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'], pm.TruncatedNormal)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['tau'], pm.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['tau'].parents['x'], pm.Uniform)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'], pm.Normal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['mu'], pm.Normal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['tau'], pm.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['tau'].parents['x'], pm.Uniform)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'], pm.TruncatedNormal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['mu'], pm.Uniform)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['tau'], pm.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['tau'].parents['x'], pm.Uniform)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'], pm.TruncatedNormal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['tau'], pm.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['tau'].parents['x'], pm.Uniform)
 
     def test_HDDM_distributions(self):
         params = hddm.generate.gen_rand_params()
         data, params_subj = hddm.generate.gen_rand_data(subjs=4, params=params, size=10)
         m = hddm.HDDM(data)
         m.sample(self.iter, burn=self.burn)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'], pm.Normal)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['mu'], pm.Normal)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['tau'], pm.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['tau'].parents['x'], pm.HalfNormal)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'], pm.Gamma)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['alpha'], pm.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['alpha'].parents['x'], pm.Gamma)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['beta'], pm.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['beta'].parents['y'], pm.HalfNormal)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'], pm.Gamma)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['alpha'], pm.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['alpha'].parents['x'], pm.Gamma)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['beta'], pm.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['beta'].parents['y'], pm.HalfNormal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'], pm.Normal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['mu'], pm.Normal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['tau'], pm.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['v'].parents['tau'].parents['x'], pm.HalfNormal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'], pm.Gamma)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['alpha'], pm.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['alpha'].parents['x'], pm.Gamma)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['beta'], pm.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['a'].parents['beta'].parents['y'], pm.HalfNormal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'], pm.Gamma)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['alpha'], pm.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['alpha'].parents['x'], pm.Gamma)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['beta'], pm.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt.0']['node'].parents['t'].parents['beta'].parents['y'], pm.HalfNormal)
 
 
     def test_HDDMStimCoding(self):
@@ -150,16 +168,26 @@ class TestSingleBreakdown(unittest.TestCase):
         data, params_subj = hddm.generate.gen_rand_data(params=params_full, size=10)
         m = hddm.HDDMStimCoding(data, stim_col='condition', split_param='v')
         m.sample(self.iter, burn=self.burn)
-        assert isinstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['v'], pm.Normal)
-        assert isinstance(m.nodes_db.ix['wfpt(c1)']['node'].parents['v'], pm.PyMCObjects.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt(c1)']['node'].parents['v'].parents['self'], pm.Normal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c1)']['node'].parents['v'], pm.Normal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['v'], pm.PyMCObjects.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['v'].parents['self'], pm.Normal)
 
         m = hddm.HDDMStimCoding(data, stim_col='condition', split_param='z')
         m.sample(self.iter, burn=self.burn)
-        assert isinstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['z'], pm.CommonDeterministics.InvLogit)
-        assert isinstance(m.nodes_db.ix['wfpt(c1)']['node'].parents['z'], pm.PyMCObjects.Deterministic)
-        assert isinstance(m.nodes_db.ix['wfpt(c1)']['node'].parents['z'].parents['a'], int)
-        assert isinstance(m.nodes_db.ix['wfpt(c1)']['node'].parents['z'].parents['b'], pm.CommonDeterministics.InvLogit)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c1)']['node'].parents['z'], pm.CommonDeterministics.InvLogit)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['z'], pm.PyMCObjects.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['z'].parents['a'], int)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['z'].parents['b'], pm.CommonDeterministics.InvLogit)
+
+        m = hddm.HDDMStimCoding(data, stim_col='condition', split_param='v', drift_criterion=True)
+        m.sample(self.iter, burn=self.burn)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c1)']['node'].parents['v'], pm.PyMCObjects.Deterministic)
+        self.assertEqual(m.nodes_db.ix['wfpt(c1)']['node'].parents['v'].parents['a'].__name__, 'v')
+        self.assertEqual(m.nodes_db.ix['wfpt(c1)']['node'].parents['v'].parents['b'].__name__, 'dc')
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['v'], pm.PyMCObjects.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['v'].parents['a'], pm.PyMCObjects.Deterministic)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['v'].parents['b'], pm.Normal)
+        self.assertIsInstance(m.nodes_db.ix['wfpt(c0)']['node'].parents['v'].parents['a'].parents['self'], pm.Normal)
 
 
 class TestHDDMRegressor(unittest.TestCase):
@@ -304,6 +332,8 @@ def test_posterior_plots_breakdown():
     m.plot_posterior_predictive()
     m.plot_posterior_quantiles()
     m.plot_posteriors()
+    ppc = hddm.utils.post_pred_gen(m, samples=10)
+    hddm.utils.post_pred_stats(data, ppc)
 
 if __name__=='__main__':
     print "Run nosetest.py"
